/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global window*/

/**
 * The templates module.
 * Provides HTML templates for all pages used in the application.
 *
 * @module app.ui.templates
 * @requires {@link app.common}
 * @namespace app.ui.templates
 * @memberof app.ui
 */

// make sure that "app" namespace is created
window.app = window.app || {};

(function defineTemplates(app) {
    'use strict';

    /**
     * Template for preferences list element.
     * All values which should be replaced with actual data are marked
     * with "%" signs.
     *
     * @memberof app.ui.templates
     * @private
     * @const {string}
     */
    var LIST_ELEMENT_TEMPLATE =
        '<li class="list-item" data-id="%id%">' +
        '<div class="list-item-key">%key%</div>' +
        '<div class="list-item-value">' +
        '<span class="item-value">%value%</span>' +
        '<span class="item-type">%type%</span>' +
        '</div>' +
        '<button class="list-item-delete-btn"></button>' +
        '</li>';

    /**
     * Returns HTML for preferences list element (template text filled
     * with specified data). All necessary values are escaped
     * with HTML entities.
     *
     * @memberof app.ui.templates
     * @public
     * @param {object} data
     * @param {string} data.id Value of the data-id attribute.
     * @param {string} data.key The key name of the preferences data value.
     * @param {string} data.value The value associated with a given key.
     * @param {string} data.type Preference value type.
     * @returns {string}
     */
    function getListElement(data) {
        return LIST_ELEMENT_TEMPLATE
            .replace('%id%', app.common.escapeHTML(data.id))
            .replace('%key%', app.common.escapeHTML(data.key))
            .replace('%value%', app.common.escapeHTML(data.value))
            .replace('%type%', app.common.escapeHTML(data.type));
    }

    app.ui = app.ui || {};
    app.ui.templates = {
        getListElement: getListElement
    };

})(window.app);
